@@ -1,34 +1,84 @@
-#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[link(name = "windows")]
-extern "system" {
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
-    #[cfg(feature = "Win32_Foundation")]
-    pub fn PssCaptureSnapshot(processhandle: super::super::super::Foundation::HANDLE, captureflags: PSS_CAPTURE_FLAGS, threadcontextflags: u32, snapshothandle: *mut HPSS) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
-    #[cfg(feature = "Win32_Foundation")]
-    pub fn PssDuplicateSnapshot(sourceprocesshandle: super::super::super::Foundation::HANDLE, snapshothandle: HPSS, targetprocesshandle: super::super::super::Foundation::HANDLE, targetsnapshothandle: *mut HPSS, flags: PSS_DUPLICATE_FLAGS) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
-    #[cfg(feature = "Win32_Foundation")]
-    pub fn PssFreeSnapshot(processhandle: super::super::super::Foundation::HANDLE, snapshothandle: HPSS) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssQuerySnapshot(snapshothandle: HPSS, informationclass: PSS_QUERY_INFORMATION_CLASS, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssWalkMarkerCreate(allocator: *const PSS_ALLOCATOR, walkmarkerhandle: *mut HPSSWALK) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssWalkMarkerFree(walkmarkerhandle: HPSSWALK) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssWalkMarkerGetPosition(walkmarkerhandle: HPSSWALK, position: *mut usize) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssWalkMarkerSeekToBeginning(walkmarkerhandle: HPSSWALK) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssWalkMarkerSetPosition(walkmarkerhandle: HPSSWALK, position: usize) -> u32;
-    #[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-    pub fn PssWalkSnapshot(snapshothandle: HPSS, informationclass: PSS_WALK_INFORMATION_CLASS, walkmarkerhandle: HPSSWALK, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32;
-}
+#[cfg(feature = "Win32_Foundation")]
+::windows_targets::link!("kernel32.dll" "system" #[doc = "Required features: `\"Win32_Foundation\"`"] fn PssCaptureSnapshot(processhandle : super::super::super::Foundation:: HANDLE, captureflags : PSS_CAPTURE_FLAGS, threadcontextflags : u32, snapshothandle : *mut HPSS) -> u32);
+#[cfg(feature = "Win32_Foundation")]
+::windows_targets::link!("kernel32.dll" "system" #[doc = "Required features: `\"Win32_Foundation\"`"] fn PssDuplicateSnapshot(sourceprocesshandle : super::super::super::Foundation:: HANDLE, snapshothandle : HPSS, targetprocesshandle : super::super::super::Foundation:: HANDLE, targetsnapshothandle : *mut HPSS, flags : PSS_DUPLICATE_FLAGS) -> u32);
+#[cfg(feature = "Win32_Foundation")]
+::windows_targets::link!("kernel32.dll" "system" #[doc = "Required features: `\"Win32_Foundation\"`"] fn PssFreeSnapshot(processhandle : super::super::super::Foundation:: HANDLE, snapshothandle : HPSS) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssQuerySnapshot(snapshothandle : HPSS, informationclass : PSS_QUERY_INFORMATION_CLASS, buffer : *mut ::core::ffi::c_void, bufferlength : u32) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssWalkMarkerCreate(allocator : *const PSS_ALLOCATOR, walkmarkerhandle : *mut HPSSWALK) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssWalkMarkerFree(walkmarkerhandle : HPSSWALK) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssWalkMarkerGetPosition(walkmarkerhandle : HPSSWALK, position : *mut usize) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssWalkMarkerSeekToBeginning(walkmarkerhandle : HPSSWALK) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssWalkMarkerSetPosition(walkmarkerhandle : HPSSWALK, position : usize) -> u32);
+::windows_targets::link!("kernel32.dll" "system" fn PssWalkSnapshot(snapshothandle : HPSS, informationclass : PSS_WALK_INFORMATION_CLASS, walkmarkerhandle : HPSSWALK, buffer : *mut ::core::ffi::c_void, bufferlength : u32) -> u32);
+pub const PSS_CAPTURE_HANDLES: PSS_CAPTURE_FLAGS = 4u32;
+pub const PSS_CAPTURE_HANDLE_BASIC_INFORMATION: PSS_CAPTURE_FLAGS = 16u32;
+pub const PSS_CAPTURE_HANDLE_NAME_INFORMATION: PSS_CAPTURE_FLAGS = 8u32;
+pub const PSS_CAPTURE_HANDLE_TRACE: PSS_CAPTURE_FLAGS = 64u32;
+pub const PSS_CAPTURE_HANDLE_TYPE_SPECIFIC_INFORMATION: PSS_CAPTURE_FLAGS = 32u32;
+pub const PSS_CAPTURE_IPT_TRACE: PSS_CAPTURE_FLAGS = 8192u32;
+pub const PSS_CAPTURE_NONE: PSS_CAPTURE_FLAGS = 0u32;
+pub const PSS_CAPTURE_RESERVED_00000002: PSS_CAPTURE_FLAGS = 2u32;
+pub const PSS_CAPTURE_RESERVED_00000400: PSS_CAPTURE_FLAGS = 1024u32;
+pub const PSS_CAPTURE_RESERVED_00004000: PSS_CAPTURE_FLAGS = 16384u32;
+pub const PSS_CAPTURE_THREADS: PSS_CAPTURE_FLAGS = 128u32;
+pub const PSS_CAPTURE_THREAD_CONTEXT: PSS_CAPTURE_FLAGS = 256u32;
+pub const PSS_CAPTURE_THREAD_CONTEXT_EXTENDED: PSS_CAPTURE_FLAGS = 512u32;
+pub const PSS_CAPTURE_VA_CLONE: PSS_CAPTURE_FLAGS = 1u32;
+pub const PSS_CAPTURE_VA_SPACE: PSS_CAPTURE_FLAGS = 2048u32;
+pub const PSS_CAPTURE_VA_SPACE_SECTION_INFORMATION: PSS_CAPTURE_FLAGS = 4096u32;
+pub const PSS_CREATE_BREAKAWAY: PSS_CAPTURE_FLAGS = 134217728u32;
+pub const PSS_CREATE_BREAKAWAY_OPTIONAL: PSS_CAPTURE_FLAGS = 67108864u32;
+pub const PSS_CREATE_FORCE_BREAKAWAY: PSS_CAPTURE_FLAGS = 268435456u32;
+pub const PSS_CREATE_MEASURE_PERFORMANCE: PSS_CAPTURE_FLAGS = 1073741824u32;
+pub const PSS_CREATE_RELEASE_SECTION: PSS_CAPTURE_FLAGS = 2147483648u32;
+pub const PSS_CREATE_USE_VM_ALLOCATIONS: PSS_CAPTURE_FLAGS = 536870912u32;
+pub const PSS_DUPLICATE_CLOSE_SOURCE: PSS_DUPLICATE_FLAGS = 1i32;
+pub const PSS_DUPLICATE_NONE: PSS_DUPLICATE_FLAGS = 0i32;
+pub const PSS_HANDLE_HAVE_BASIC_INFORMATION: PSS_HANDLE_FLAGS = 4i32;
+pub const PSS_HANDLE_HAVE_NAME: PSS_HANDLE_FLAGS = 2i32;
+pub const PSS_HANDLE_HAVE_TYPE: PSS_HANDLE_FLAGS = 1i32;
+pub const PSS_HANDLE_HAVE_TYPE_SPECIFIC_INFORMATION: PSS_HANDLE_FLAGS = 8i32;
+pub const PSS_HANDLE_NONE: PSS_HANDLE_FLAGS = 0i32;
+pub const PSS_OBJECT_TYPE_EVENT: PSS_OBJECT_TYPE = 4i32;
+pub const PSS_OBJECT_TYPE_MUTANT: PSS_OBJECT_TYPE = 3i32;
+pub const PSS_OBJECT_TYPE_PROCESS: PSS_OBJECT_TYPE = 1i32;
+pub const PSS_OBJECT_TYPE_SECTION: PSS_OBJECT_TYPE = 5i32;
+pub const PSS_OBJECT_TYPE_SEMAPHORE: PSS_OBJECT_TYPE = 6i32;
+pub const PSS_OBJECT_TYPE_THREAD: PSS_OBJECT_TYPE = 2i32;
+pub const PSS_OBJECT_TYPE_UNKNOWN: PSS_OBJECT_TYPE = 0i32;
+pub const PSS_PERF_RESOLUTION: u32 = 1000000u32;
+pub const PSS_PROCESS_FLAGS_FROZEN: PSS_PROCESS_FLAGS = 16i32;
+pub const PSS_PROCESS_FLAGS_NONE: PSS_PROCESS_FLAGS = 0i32;
+pub const PSS_PROCESS_FLAGS_PROTECTED: PSS_PROCESS_FLAGS = 1i32;
+pub const PSS_PROCESS_FLAGS_RESERVED_03: PSS_PROCESS_FLAGS = 4i32;
+pub const PSS_PROCESS_FLAGS_RESERVED_04: PSS_PROCESS_FLAGS = 8i32;
+pub const PSS_PROCESS_FLAGS_WOW64: PSS_PROCESS_FLAGS = 2i32;
+pub const PSS_QUERY_AUXILIARY_PAGES_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 2i32;
+pub const PSS_QUERY_HANDLE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 4i32;
+pub const PSS_QUERY_HANDLE_TRACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 6i32;
+pub const PSS_QUERY_PERFORMANCE_COUNTERS: PSS_QUERY_INFORMATION_CLASS = 7i32;
+pub const PSS_QUERY_PROCESS_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 0i32;
+pub const PSS_QUERY_THREAD_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 5i32;
+pub const PSS_QUERY_VA_CLONE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 1i32;
+pub const PSS_QUERY_VA_SPACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 3i32;
+pub const PSS_THREAD_FLAGS_NONE: PSS_THREAD_FLAGS = 0i32;
+pub const PSS_THREAD_FLAGS_TERMINATED: PSS_THREAD_FLAGS = 1i32;
+pub const PSS_WALK_AUXILIARY_PAGES: PSS_WALK_INFORMATION_CLASS = 0i32;
+pub const PSS_WALK_HANDLES: PSS_WALK_INFORMATION_CLASS = 2i32;
+pub const PSS_WALK_THREADS: PSS_WALK_INFORMATION_CLASS = 3i32;
+pub const PSS_WALK_VA_SPACE: PSS_WALK_INFORMATION_CLASS = 1i32;
+pub type PSS_CAPTURE_FLAGS = u32;
+pub type PSS_DUPLICATE_FLAGS = i32;
+pub type PSS_HANDLE_FLAGS = i32;
+pub type PSS_OBJECT_TYPE = i32;
+pub type PSS_PROCESS_FLAGS = i32;
+pub type PSS_QUERY_INFORMATION_CLASS = i32;
+pub type PSS_THREAD_FLAGS = i32;
+pub type PSS_WALK_INFORMATION_CLASS = i32;
 pub type HPSS = isize;
 pub type HPSSWALK = isize;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_ALLOCATOR {
     pub Context: *mut ::core::ffi::c_void,
     pub AllocRoutine: isize,
@@ -41,7 +91,6 @@ impl ::core::clone::Clone for PSS_ALLOCATOR {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_AUXILIARY_PAGES_INFORMATION {
     pub AuxPagesCaptured: u32,
 }
@@ -52,7 +101,7 @@ impl ::core::clone::Clone for PSS_AUXILIARY_PAGES_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation', 'Win32_System_Memory'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`, `\"Win32_System_Memory\"`"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Memory"))]
 pub struct PSS_AUXILIARY_PAGE_ENTRY {
     pub Address: *mut ::core::ffi::c_void,
@@ -69,60 +118,8 @@ impl ::core::clone::Clone for PSS_AUXILIARY_PAGE_ENTRY {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_CAPTURE_FLAGS = u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_NONE: PSS_CAPTURE_FLAGS = 0u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_VA_CLONE: PSS_CAPTURE_FLAGS = 1u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_RESERVED_00000002: PSS_CAPTURE_FLAGS = 2u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_HANDLES: PSS_CAPTURE_FLAGS = 4u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_HANDLE_NAME_INFORMATION: PSS_CAPTURE_FLAGS = 8u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_HANDLE_BASIC_INFORMATION: PSS_CAPTURE_FLAGS = 16u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_HANDLE_TYPE_SPECIFIC_INFORMATION: PSS_CAPTURE_FLAGS = 32u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_HANDLE_TRACE: PSS_CAPTURE_FLAGS = 64u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_THREADS: PSS_CAPTURE_FLAGS = 128u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_THREAD_CONTEXT: PSS_CAPTURE_FLAGS = 256u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_THREAD_CONTEXT_EXTENDED: PSS_CAPTURE_FLAGS = 512u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_RESERVED_00000400: PSS_CAPTURE_FLAGS = 1024u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_VA_SPACE: PSS_CAPTURE_FLAGS = 2048u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_VA_SPACE_SECTION_INFORMATION: PSS_CAPTURE_FLAGS = 4096u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_IPT_TRACE: PSS_CAPTURE_FLAGS = 8192u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CAPTURE_RESERVED_00004000: PSS_CAPTURE_FLAGS = 16384u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CREATE_BREAKAWAY_OPTIONAL: PSS_CAPTURE_FLAGS = 67108864u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CREATE_BREAKAWAY: PSS_CAPTURE_FLAGS = 134217728u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CREATE_FORCE_BREAKAWAY: PSS_CAPTURE_FLAGS = 268435456u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CREATE_USE_VM_ALLOCATIONS: PSS_CAPTURE_FLAGS = 536870912u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CREATE_MEASURE_PERFORMANCE: PSS_CAPTURE_FLAGS = 1073741824u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_CREATE_RELEASE_SECTION: PSS_CAPTURE_FLAGS = 2147483648u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_DUPLICATE_FLAGS = u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_DUPLICATE_NONE: PSS_DUPLICATE_FLAGS = 0u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_DUPLICATE_CLOSE_SOURCE: PSS_DUPLICATE_FLAGS = 1u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY {
     pub Handle: super::super::super::Foundation::HANDLE,
@@ -151,7 +148,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub union PSS_HANDLE_ENTRY_0 {
     pub Process: PSS_HANDLE_ENTRY_0_2,
@@ -170,7 +167,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_0 {
     pub ManualReset: super::super::super::Foundation::BOOL,
@@ -185,7 +182,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_1 {
     pub CurrentCount: i32,
@@ -202,7 +199,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_1 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_2 {
     pub ExitStatus: u32,
@@ -222,7 +219,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_2 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_3 {
     pub BaseAddress: *mut ::core::ffi::c_void,
@@ -238,7 +235,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_3 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_4 {
     pub CurrentCount: i32,
@@ -253,7 +250,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_4 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_5 {
     pub ExitStatus: u32,
@@ -273,20 +270,7 @@ impl ::core::clone::Clone for PSS_HANDLE_ENTRY_0_5 {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_HANDLE_FLAGS = u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_HANDLE_NONE: PSS_HANDLE_FLAGS = 0u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_HANDLE_HAVE_TYPE: PSS_HANDLE_FLAGS = 1u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_HANDLE_HAVE_NAME: PSS_HANDLE_FLAGS = 2u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_HANDLE_HAVE_BASIC_INFORMATION: PSS_HANDLE_FLAGS = 4u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_HANDLE_HAVE_TYPE_SPECIFIC_INFORMATION: PSS_HANDLE_FLAGS = 8u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_HANDLE_INFORMATION {
     pub HandlesCaptured: u32,
 }
@@ -297,7 +281,7 @@ impl ::core::clone::Clone for PSS_HANDLE_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_TRACE_INFORMATION {
     pub SectionHandle: super::super::super::Foundation::HANDLE,
@@ -311,24 +295,7 @@ impl ::core::clone::Clone for PSS_HANDLE_TRACE_INFORMATION {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_OBJECT_TYPE = i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_UNKNOWN: PSS_OBJECT_TYPE = 0i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_PROCESS: PSS_OBJECT_TYPE = 1i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_THREAD: PSS_OBJECT_TYPE = 2i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_MUTANT: PSS_OBJECT_TYPE = 3i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_EVENT: PSS_OBJECT_TYPE = 4i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_SECTION: PSS_OBJECT_TYPE = 5i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_OBJECT_TYPE_SEMAPHORE: PSS_OBJECT_TYPE = 6i32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_PERFORMANCE_COUNTERS {
     pub TotalCycleCount: u64,
     pub TotalWallClockPeriod: u64,
@@ -349,24 +316,8 @@ impl ::core::clone::Clone for PSS_PERFORMANCE_COUNTERS {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PERF_RESOLUTION: u32 = 1000000u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_PROCESS_FLAGS = u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PROCESS_FLAGS_NONE: PSS_PROCESS_FLAGS = 0u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PROCESS_FLAGS_PROTECTED: PSS_PROCESS_FLAGS = 1u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PROCESS_FLAGS_WOW64: PSS_PROCESS_FLAGS = 2u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PROCESS_FLAGS_RESERVED_03: PSS_PROCESS_FLAGS = 4u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PROCESS_FLAGS_RESERVED_04: PSS_PROCESS_FLAGS = 8u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_PROCESS_FLAGS_FROZEN: PSS_PROCESS_FLAGS = 16u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_PROCESS_INFORMATION {
     pub ExitStatus: u32,
@@ -404,26 +355,8 @@ impl ::core::clone::Clone for PSS_PROCESS_INFORMATION {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_QUERY_INFORMATION_CLASS = i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_PROCESS_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 0i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_VA_CLONE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 1i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_AUXILIARY_PAGES_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 2i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_VA_SPACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 3i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_HANDLE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 4i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_THREAD_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 5i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_HANDLE_TRACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = 6i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_QUERY_PERFORMANCE_COUNTERS: PSS_QUERY_INFORMATION_CLASS = 7i32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Kernel\"`"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
 pub struct PSS_THREAD_ENTRY {
     pub ExitStatus: u32,
@@ -454,14 +387,7 @@ impl ::core::clone::Clone for PSS_THREAD_ENTRY {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_THREAD_FLAGS = u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_THREAD_FLAGS_NONE: PSS_THREAD_FLAGS = 0u32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_THREAD_FLAGS_TERMINATED: PSS_THREAD_FLAGS = 1u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_THREAD_INFORMATION {
     pub ThreadsCaptured: u32,
     pub ContextLength: u32,
@@ -473,7 +399,7 @@ impl ::core::clone::Clone for PSS_THREAD_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[doc = "Required features: `\"Win32_Foundation\"`"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_VA_CLONE_INFORMATION {
     pub VaCloneHandle: super::super::super::Foundation::HANDLE,
@@ -487,7 +413,6 @@ impl ::core::clone::Clone for PSS_VA_CLONE_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_VA_SPACE_ENTRY {
     pub BaseAddress: *mut ::core::ffi::c_void,
     pub AllocationBase: *mut ::core::ffi::c_void,
@@ -510,7 +435,6 @@ impl ::core::clone::Clone for PSS_VA_SPACE_ENTRY {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_VA_SPACE_INFORMATION {
     pub RegionCount: u32,
 }
@@ -520,13 +444,3 @@ impl ::core::clone::Clone for PSS_VA_SPACE_INFORMATION {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub type PSS_WALK_INFORMATION_CLASS = i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_WALK_AUXILIARY_PAGES: PSS_WALK_INFORMATION_CLASS = 0i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_WALK_VA_SPACE: PSS_WALK_INFORMATION_CLASS = 1i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_WALK_HANDLES: PSS_WALK_INFORMATION_CLASS = 2i32;
-#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
-pub const PSS_WALK_THREADS: PSS_WALK_INFORMATION_CLASS = 3i32;
